==> mosaicml-0.2.3.tar.gz: mosaicml-0.2.3/composer/optim/__init__.py <==
# Copyright 2021 MosaicML. All Rights Reserved.

from composer.optim.decoupled_weight_decay import DecoupledAdamW as DecoupledAdamW
from composer.optim.decoupled_weight_decay import DecoupledSGDW as DecoupledSGDW
from composer.optim.optimizer_hparams import AdamHparams as AdamHparams
from composer.optim.optimizer_hparams import AdamWHparams as AdamWHparams
from composer.optim.optimizer_hparams import DecoupledAdamWHparams as DecoupledAdamWHparams
from composer.optim.optimizer_hparams import DecoupledSGDWHparams as DecoupledSGDWHparams
from composer.optim.optimizer_hparams import OptimizerHparams as OptimizerHparams
from composer.optim.optimizer_hparams import RAdamHparams as RAdamHparams
from composer.optim.optimizer_hparams import RMSPropHparams as RMSPropHparams
from composer.optim.optimizer_hparams import SGDHparams as SGDHparams
from composer.optim.pytorch_future import WarmUpLR as WarmUpLR
from composer.optim.scheduler import ComposedScheduler as ComposedScheduler
from composer.optim.scheduler import ConstantLR as ConstantLR
from composer.optim.scheduler import ConstantLRHparams as ConstantLRHparams
from composer.optim.scheduler import CosineAnnealingLRHparams as CosineAnnealingLRHparams
from composer.optim.scheduler import CosineAnnealingWarmRestartsHparams as CosineAnnealingWarmRestartsHparams
from composer.optim.scheduler import ExponentialLRHparams as ExponentialLRHparams
from composer.optim.scheduler import MultiStepLRHparams as MultiStepLRHparams
from composer.optim.scheduler import SchedulerHparams as SchedulerHparams
from composer.optim.scheduler import StepLRHparams as StepLRHparams
from composer.optim.scheduler import WarmUpLRHparams as WarmUpLRHparams

==> mosaicml-0.4.0.tar.gz: mosaicml-0.4.0/composer/optim/__init__.py <==
# Copyright 2021 MosaicML. All Rights Reserved.

from composer.optim.decoupled_weight_decay import DecoupledAdamW as DecoupledAdamW
from composer.optim.decoupled_weight_decay import DecoupledSGDW as DecoupledSGDW
from composer.optim.optimizer_hparams import AdamHparams as AdamHparams
from composer.optim.optimizer_hparams import AdamWHparams as AdamWHparams
from composer.optim.optimizer_hparams import DecoupledAdamWHparams as DecoupledAdamWHparams
from composer.optim.optimizer_hparams import DecoupledSGDWHparams as DecoupledSGDWHparams
from composer.optim.optimizer_hparams import OptimizerHparams as OptimizerHparams
from composer.optim.optimizer_hparams import RAdamHparams as RAdamHparams
from composer.optim.optimizer_hparams import RMSPropHparams as RMSPropHparams
from composer.optim.optimizer_hparams import SGDHparams as SGDHparams
from composer.optim.scheduler import ConstantLRHparams as ConstantLRHparams
from composer.optim.scheduler import CosineAnnealingLRHparams as CosineAnnealingLRHparams
from composer.optim.scheduler import CosineAnnealingWarmRestartsHparams as CosineAnnealingWarmRestartsHparams
from composer.optim.scheduler import CosineAnnealingWithWarmupLRHparams as CosineAnnealingWithWarmupLRHparams
from composer.optim.scheduler import ExponentialLRHparams as ExponentialLRHparams
from composer.optim.scheduler import LinearLRHparams as LinearLRHparams
from composer.optim.scheduler import LinearWithWarmupLRHparams as LinearWithWarmupLRHparams
from composer.optim.scheduler import MultiStepLRHparams as MultiStepLRHparams
from composer.optim.scheduler import MultiStepWithWarmupLRHparams as MultiStepWithWarmupLRHparams
from composer.optim.scheduler import PolynomialLRHparams as PolynomialLRHparams
from composer.optim.scheduler import SchedulerHparams as SchedulerHparams
from composer.optim.scheduler import StepLRHparams as StepLRHparams
